
[![version](https://img.shields.io/pypi/v/climap?color=green)](https://pypi.org/project/climap/)
[![supports](https://img.shields.io/pypi/pyversions/climap?color=blue&label=supports)](https://pypi.org/project/climap/)
[![test coverage](https://codecov.io/gh/symonk/climap/branch/main/graph/badge.svg)](https://codecov.io/gh/symonk/climap)
[![docs](https://img.shields.io/badge/documentation-online-brightgreen.svg)](https://symonk.github.io/climap/)


# climap (**ALPHA**)

-----

A rich-based command line utility for IMAP. Written solely in python.
